### Name: caFromRatio
### Title: Get Calcium Concentration From Fluorescence Signals, Using the
###   Ratiometric Transformation
### Aliases: caFromRatio


### ** Examples

## (0) "Experimental" parameters

## Parameters of the monoexponential calcium transient
tOn <- 1
Time <- seq(0,10,0.1)
Ca0 <- 0.10
dCa <- 0.25
tau <- 1.5

## Calibration parameters
R_min <- list(value=0.136, mean=0.136, se=0.00363, USE_se=TRUE)
R_max <- list(value=2.701, mean=2.701, se=0.151,   USE_se=TRUE)
K_eff <- list(value=3.637, mean=3.637, se=0.729,   USE_se=TRUE)
K_d   <- list(value=0.583, mean=0.583, se=0.123,   USE_se=TRUE)

## Experiment-specific parameters
nb_B    <- 5
B_T     <- 100.0
T_340   <- 0.015
T_380   <- 0.006
P       <- 1000
P_B     <- 1000
phi     <- 1.25
S_B_340 <- 100/P/T_340
S_B_380 <- 100/P/T_380

## (1) Create a monoexponential calcium decay
Ca_Mono <- caMonoExp(t = Time, tOn = tOn,
                     Ca0 = Ca0, dCa = dCa, tau = tau)

## (2) Create the background and transient fluorescence signals
adu_B_340 <- rep(fluo(Ca=rep(0,nb_B),
                      R_min=R_min$value, R_max=R_max$value,
                      K_eff=K_eff$value, K_d=K_d$value,
                      B_T=0, phi=phi, S_B=S_B_340, T_stim=T_340, P=P, P_B=P_B))
  
adu_340 <- rep(fluo(Ca=Ca_Mono,
                    R_min=R_min$value, R_max=R_max$value,
                    K_eff=K_eff$value, K_d=K_d$value,
                    B_T=B_T, phi=phi, S_B=S_B_340, T_stim=T_340, P=P, P_B=P_B))

adu_B_380 <- rep(fluo(Ca=rep(0,nb_B),
                      R_min=1, R_max=1, K_eff=K_eff$value, K_d=K_d$value,
                      B_T=0, phi=phi, S_B=S_B_380, T_stim=T_380, P=P, P_B=P_B))
  
adu_380 <- rep(fluo(Ca=Ca_Mono,
                    R_min=1, R_max=1, K_eff=K_eff$value, K_d=K_d$value,
                    B_T=B_T, phi=phi, S_B=S_B_380, T_stim=T_380, P=P, P_B=P_B))

## (3) Get the noisy calcium transient from the ratiometric transformation
Ca <- caFromRatio(adu_B_340, adu_340,
                  adu_B_380, adu_380,
                  T_340 = 0.015, T_380 = 0.006,
                  P, P_B,
                  R_min = R_min, R_max = R_max, K_eff = K_eff,
                  Plot = TRUE)

## (4) Superimpose the original calcium transient
lines(Ca_Mono, lty=2, col="red")



