### Name: fluo
### Title: Convert Intracellular Calcium Concentration into Fluorescence
###   Values
### Aliases: fluo


### ** Examples

## Parameters of the monoexponential calcium transient
tOn  <- 1
Time <- seq(0,12,length.out=160)
Ca0  <- 0.10
dCa  <- 0.25
tau  <- 1.5

## Calibrated parameters
R_min <- 0.136
R_max <- 2.701
K_eff <- 3.637
K_d <- 0.583

## Experiment-specific parameters
nb_B    <- 1
B_T     <- 100.0
T_340   <- 0.015
T_380   <- 0.006
P       <- 200
P_B     <- 200
phi     <- 2
S_B_340 <- 30
S_B_380 <- 80

## Create a monoexponential calcium decay
Ca <- caMonoExp(t = Time, tOn = tOn,
                Ca0 = Ca0, dCa = dCa, tau = tau)

## Define Background and Signal fluorescences at 340 and 380 nm
B_340 <- fluo(Ca=rep(0,nb_B), R_min=R_min, R_max=R_max, K_eff=K_eff, K_d=K_d,
              B_T=0, phi=phi, S_B=S_B_340, T_stim=T_340, P=P, P_B=P_B)

F_340 <- fluo(Ca=Ca, R_min=R_min, R_max=R_max, K_eff=K_eff, K_d=K_d,
              B_T=B_T, phi=phi, S_B=S_B_340, T_stim=T_340, P=P, P_B=P_B)
  
B_380 <- fluo(Ca=rep(0,nb_B), R_min=1, R_max=1, K_eff=K_eff, K_d=K_d,
              B_T=0, phi=phi, S_B=S_B_380, T_stim=T_380, P=P, P_B=P_B)

F_380 <- fluo(Ca=Ca, R_min=1, R_max=1, K_eff=K_eff, K_d=K_d,
              B_T=B_T, phi=phi, S_B=S_B_380, T_stim=T_380, P=P, P_B=P_B)

## Plot the fluorescence transients at 340 and 380 nm
layout(matrix(1:2,nrow=2))
plot(Time, F_340, type="l", bty="n")
plot(Time, F_380, type="l", bty="n")



