### Name: mkFunction4DirectFit
### Title: Function for Direct Fit
### Aliases: mkFunction4DirectFit


### ** Examples

## Parameters of the biexponential calcium transient
tOn  <- 1
Time <- seq(0,12,length.out=160)
Ca0  <- 0.10
dCa  <- 0.25
tau  <- 1.5
mu   <- 0
dtau <- 10

## Calibrated parameters
R_min <- 0.136
R_max <- 2.701
K_eff <- 3.637
K_d   <- 0.583

## Experiment-specific parameters
B_T     <- 100.0
T_340   <- 0.015
T_380   <- 0.006
P       <- 200
P_B     <- 200
phi     <- 2
S_B_340 <- 30
S_B_380 <- 80

## Define a function for fluorescence transients based on
## a monoexponential calcium concentration time course
Fluo_bi_fct <- mkFunction4DirectFit(type = "bi",
                                    nb_B = 5,
                                    transients = 1,
                                    alphamethod = FALSE,
                                    SQRT = TRUE)

## Create the fluorescence transients
Time <- matrix(Time, nrow=1, dimnames=list("1",NULL))
names(tOn) <- "1"
Fluo_bi <- Fluo_bi_fct(t = Time, tOn = tOn,
                       T_340 = T_340, T_380 = T_380,
                       P = P, P_B = P_B,
                       log_Ca0_1 = log(Ca0),
                       log_dCa_1 = log(dCa),
                       log_tau_1 = log(tau),
                       mu_1 = mu,
                       log_dtau_1 = log(dtau),
                       log_phi = log(phi),
                       log_S_B_340 = log(S_B_340),
                       log_S_B_380 = log(S_B_380),
                       log_R_min = log(R_min), log_R_max = log(R_max),
                       log_K_eff = log(K_eff), log_K_d = log(K_d),
                       B_T = B_T)



