### Name: plot.fluo_rawdata
### Title: Plot Function for Objects of Class "fluo_rawdata"
### Aliases: plot.fluo_rawdata


### ** Examples

## Load the data from cockroach olfactory interneurons
data(inVitro)

## Calibrated parameters
R_min <- list(value=0.136, mean=0.136, se=0.00363, USE_se=TRUE)
R_max <- list(value=2.701, mean=2.701, se=0.151,   USE_se=TRUE)
K_eff <- list(value=3.637, mean=3.637, se=0.729,   USE_se=TRUE)
K_d   <- list(value=0.583, mean=0.583, se=0.123,   USE_se=TRUE)

## Create the data frame containing the physiological data
## (experiment #2, stimulation #2)
## G and s_ro are the respectively the gain of the CCD camera
## and the standard deviation of its read-out process
physioData <- ratioExpPhysio(dataset="inVitro",
                             expe=2, stim=2,
                             idxOn=10,
                             R_min=R_min, R_max=R_max,
                             K_eff=K_eff, K_d=K_d,
                             G=0.146, s_ro=16.4,
                             alphamethod=TRUE)

## Plot fluorescence transients and the calcium transient
## obtained after ratiometric transformation
plot(x = physioData, numTransient = 2, items=1:3)

## Wait for user action
## plot(x = physioData, numTransient = 2, items=1:3, ask = TRUE,
##      xlabs = c("Time (s)", "Time (s)", "Time (s)"))



