### Name: ratioExpSimul
### Title: Simulate Ratiometric Experiment
### Aliases: ratioExpSimul


### ** Examples

## Parameters of the monoexponential calcium transient
tOn  <- 1
Time <- seq(0,12,length.out=160)
Ca0  <- 0.10
dCa  <- 0.25
tau  <- 1.5

## Calibrated parameters
R_min <- list(value=0.136, mean=0.136, se=0.00363, USE_se=FALSE)
R_max <- list(value=2.701, mean=2.701, se=0.151,   USE_se=FALSE)
K_eff <- list(value=3.637, mean=3.637, se=0.729,   USE_se=FALSE)
K_d   <- list(value=0.583, mean=0.583, se=0.123,   USE_se=FALSE)

## Experiment-specific parameters
nb_B    <- 1
B_T     <- 100.0
T_340   <- 0.015
T_380   <- 0.006
P       <- 200
P_B     <- 200
phi     <- 2
S_B_340 <- 30
S_B_380 <- 80

## Create a monoexponential calcium decay
Ca <- caMonoExp(t = Time, tOn = tOn,
                Ca0 = Ca0, dCa = dCa, tau = tau)

## Simulate the corresponding ratiometric experiment
simulData <- ratioExpSimul(nb_B    = nb_B,
                           Ca      = Ca,
                           R_min   = R_min,
                           R_max   = R_max,
                           K_eff   = K_eff,
                           K_d     = K_d,
                           B_T     = B_T,
                           phi     = phi,
                           S_B_340 = S_B_340,
                           S_B_380 = S_B_380,
                           T_340   = T_340,
                           T_380   = T_380,
                           P       = P,
                           P_B     = P_B,
                           ntransients = 1,
                           G       = 1,
                           s_ro    = 0)

## Plot the raw data
plot(simulData, numTransient=1)



